@@ -1,9 +1,16 @@
-/* sgksx1.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -15,25 +22,23 @@ static integer c__0 = 0;
 static logical c_true = TRUE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
+    static real ux1, ux2, uy1, uy2, uxc, uyc;
+    static integer iws;
     extern /* Subroutine */ int sgcls_(void), sgfrm_(void), sgopn_(integer *),
 	     sglset_(char *, logical *, ftnlen), sgqwnd_(real *, real *, real 
 	    *, real *), sgpwsn_(void), sglnzu_(real *, real *, real *, real *,
-	     integer *);
-    static real ux1, ux2, uy1, uy2;
-    extern /* Subroutine */ int sgtxzu_(real *, real *, char *, real *, 
-	    integer *, integer *, integer *, ftnlen), sgtxzv_(real *, real *, 
-	    char *, real *, integer *, integer *, integer *, ftnlen);
-    static real uxc, uyc;
-    static integer iws;
+	     integer *), sgtxzu_(real *, real *, char *, real *, integer *, 
+	    integer *, integer *, ftnlen), sgtxzv_(real *, real *, char *, 
+	    real *, integer *, integer *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 6, 0, 0, 0 };
