@@ -1,9 +1,16 @@
-/* u2df07.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -21,9 +28,9 @@ static real c_b20 = .8f;
 static integer c__19 = 19;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     integer i__1;
@@ -35,12 +42,13 @@ static integer c__19 = 19;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
-    static real alat;
-    extern integer imod_(integer *, integer *);
-    static real alon, slat;
     static integer i__, j;
     static real p[361]	/* was [19][19] */, u[361]	/* was [19][19] */, v[
 	    361]	/* was [19][19] */;
+    static integer iws;
+    static real alat;
+    extern integer imod_(integer *, integer *);
+    static real alon, slat;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
     static real rmiss;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen), gllset_(char 
@@ -48,7 +56,6 @@ static integer c__19 = 19;
 	    *, integer *, integer *), grswnd_(real *, real *, real *, real *),
 	     grstrf_(void), usdaxs_(void), grstrn_(integer *), sgpwsn_(void), 
 	    grsvpt_(real *, real *, real *, real *);
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___10 = { 0, 6, 0, 0, 0 };
