@@ -1,9 +1,16 @@
-/* umpk01.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -30,9 +37,9 @@ static real c_b43 = .03f;
 static integer c__0 = 0;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Initialized data */
 
@@ -48,8 +55,8 @@ static integer c__0 = 0;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
+    static integer i__, iws;
     static char cttl[32];
-    static integer i__;
     extern /* Subroutine */ int sgcls_(void), sgfrm_(void), sldiv_(char *, 
 	    integer *, integer *, ftnlen), slrat_(real *, real *), sgopn_(
 	    integer *), umpglb_(void), umpmap_(char *, ftnlen), sglset_(char *
@@ -61,7 +68,6 @@ static integer c__0 = 0;
 	     real *), slpvpr_(integer *), slpwwr_(integer *), sgstxy_(real *, 
 	    real *, real *, real *), sgtxzr_(real *, real *, char *, real *, 
 	    integer *, integer *, integer *, ftnlen);
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___3 = { 0, 6, 0, 0, 0 };
