@@ -1,9 +1,16 @@
-/* uupk02.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -18,9 +25,9 @@ static integer c__4 = 4;
 static integer c__21 = 21;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1;
@@ -34,18 +41,17 @@ static integer c__21 = 21;
     /* Local variables */
     static real a[5];
     static integer i__, j;
-    static real t;
-    extern /* Subroutine */ int uherb_(integer *, real *, real *, real *), 
-	    grcls_(void), grfrm_(void), uverb_(integer *, real *, real *, 
-	    real *), gropn_(integer *), uumrk_(integer *, real *, real *);
-    static real x0[20], x1[20], x2[20], y0[20], y1[20], y2[20];
+    static real t, x0[20], x1[20], x2[20], y0[20], y1[20], y2[20];
     static integer jj;
     static real dt, pi, dy, yy;
-    extern /* Subroutine */ int uusebi_(integer *), sglset_(char *, logical *,
-	     ftnlen), grstrf_(void), usdaxs_(void), uusebt_(integer *), 
-	    uspfit_(void), uusmki_(integer *), sgpwsn_(void), uusmkt_(integer 
-	    *), usspnt_(integer *, real *, real *);
     static integer iws;
+    extern /* Subroutine */ int uherb_(integer *, real *, real *, real *), 
+	    grcls_(void), grfrm_(void), uverb_(integer *, real *, real *, 
+	    real *), gropn_(integer *), uumrk_(integer *, real *, real *), 
+	    uusebi_(integer *), sglset_(char *, logical *, ftnlen), grstrf_(
+	    void), usdaxs_(void), uusebt_(integer *), uspfit_(void), uusmki_(
+	    integer *), sgpwsn_(void), uusmkt_(integer *), usspnt_(integer *, 
+	    real *, real *);
 
     /* Fortran I/O blocks */
     static cilist io___16 = { 0, 6, 0, 0, 0 };
@@ -72,7 +78,7 @@ static integer c__21 = 21;
 /* L150: */
 	}
 	y0[i__ - 1] = (y1[i__ - 1] + y2[i__ - 1]) / 2.f;
-	dy = (r__1 = y1[i__ - 1] - y2[i__ - 1], dabs(r__1));
+	dy = (r__1 = y1[i__ - 1] - y2[i__ - 1], abs(r__1));
 	x1[i__ - 1] = x0[i__ - 1] - dy / 5;
 	x2[i__ - 1] = x0[i__ - 1] + dy / 5;
 /* L100: */
