@@ -1,9 +1,16 @@
-/* color3.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -25,9 +32,9 @@ static logical c_true = TRUE_;
 static real c_b39 = .1f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1, r__2;
@@ -38,20 +45,18 @@ static real c_b39 = .1f;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
-    static integer ipat;
-    static real tlev1, tlev2;
     static integer i__, j, k;
-    static real p[441]	/* was [21][21] */, x, y;
-    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
-    static real dp, pi[114]	/* was [2][57] */;
-    extern /* Subroutine */ int uzfact_(real *), uetone_(real *, integer *, 
-	    integer *, integer *), grswnd_(real *, real *, real *, real *), 
-	    grstrf_(void), usdaxs_(void), sgpwsn_(void), grstrn_(integer *), 
-	    uestlv_(real *, real *, integer *), uyaxdv_(char *, real *, real *
-	    , ftnlen), grsvpt_(real *, real *, real *, real *), slpvpr_(
-	    integer *), uzlset_(char *, logical *, ftnlen), uysfmt_(char *, 
-	    ftnlen);
-    static integer iws;
+    static real p[441]	/* was [21][21] */, x, y, dp, pi[114]	/* was [2][57]
+	     */;
+    static integer iws, ipat;
+    static real tlev1, tlev2;
+    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
+	     uzfact_(real *), uetone_(real *, integer *, integer *, integer *)
+	    , grswnd_(real *, real *, real *, real *), grstrf_(void), usdaxs_(
+	    void), grstrn_(integer *), uyaxdv_(char *, real *, real *, ftnlen)
+	    , sgpwsn_(void), uestlv_(real *, real *, integer *), grsvpt_(real 
+	    *, real *, real *, real *), slpvpr_(integer *), uzlset_(char *, 
+	    logical *, ftnlen), uysfmt_(char *, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 6, 0, 0, 0 };
@@ -94,7 +99,7 @@ static real c_b39 = .1f;
     }
     uetone_(p, &c__21, &c__21, &c__21);
     usdaxs_();
-/* -- ȡС ---- */
+/* -- トーンバー ---- */
     grswnd_(&c_b20, &c_b21, &c_b20, &c_b21);
     grsvpt_(&c_b24, &c_b25, &c_b11, &c_b12);
     grstrn_(&c__1);
