@@ -1,9 +1,16 @@
-/* uspac1.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,9 +20,9 @@ static integer c__3 = 3;
 static integer c__51 = 51;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
@@ -24,10 +31,10 @@ static integer c__51 = 51;
     /* Local variables */
     static integer n;
     static real r__, x[51], y[51];
+    static integer iws;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     usgrph_(integer *, real *, real *), sgpwsn_(void), ussttl_(char *
 	    , char *, char *, char *, ftnlen, ftnlen, ftnlen, ftnlen);
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___5 = { 0, 6, 0, 0, 0 };
@@ -51,8 +58,8 @@ static integer c__51 = 51;
     e_rsle();
     gropn_(&iws);
     grfrm_();
-    ussttl_("TIME", "YEAR", "HEAT FLUX", "W/m|2\"", (ftnlen)4, (ftnlen)4, (
-	    ftnlen)9, (ftnlen)6);
+    ussttl_("TIME", "YEAR", "HEAT FLUX", "W/m^2", (ftnlen)4, (ftnlen)4, (
+	    ftnlen)9, (ftnlen)5);
     usgrph_(&c__51, x, y);
     grcls_();
     return 0;
