@@ -1,9 +1,16 @@
-/* szm3zv.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -28,7 +35,7 @@ struct {
 #define szbtx3_1 szbtx3_
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szm3zv_(integer *n, real *vpx, real *vpy, real *vpz)
 {
@@ -37,10 +44,10 @@ struct {
 
     /* Local variables */
     static integer i__;
+    static real rx, ry;
     static logical lflag;
     extern /* Subroutine */ int stepr2_(void), stfpr3_(real *, real *, real *,
 	     real *, real *), strpr2_(void);
-    static real rx, ry;
     static logical lclipz;
     extern /* Subroutine */ int sztxzv_(real *, real *, char *, ftnlen);
 
