@@ -1,9 +1,16 @@
-/* szoplv.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -20,17 +27,16 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     PLOT ROUTINE ON VC (CLIPPING) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szoplv_0_(int n__, real *vx, real *vy)
 {
+    static real xx, yy, vx0, vy0;
     static logical lcont, lmove, lvalid;
-    static real xx, yy;
     extern /* Subroutine */ int szcllc_(void), szgcll_(real *, real *, 
 	    logical *, logical *, integer *), szpcll_(real *, real *, real *, 
 	    real *, logical *, integer *), szpllc_(real *, real *), szoplc_(
 	    void), szmvlc_(real *, real *);
-    static real vx0, vy0;
 
     switch(n__) {
 	case 1: goto L_szmvlv;
