@@ -18,8 +18,8 @@ static real c_b13 = 1.f;
 static logical c_true = TRUE_;
 static integer c__10 = 10;
 static integer c__1 = 1;
-static real c_b28 = 10.f;
-static integer c__4 = 4;
+static real c_b29 = 10.f;
+static integer c__3 = 3;
 static integer c__2 = 2;
 static integer c__16 = 16;
 
@@ -30,8 +30,8 @@ static integer c__16 = 16;
 	ftnlen cside_len)
 {
     /* System generated locals */
-    address a__1[4], a__2[2];
-    integer i__1, i__2, i__3, i__4[4], i__5[2];
+    address a__1[3], a__2[2];
+    integer i__1, i__2, i__3, i__4[3], i__5[2];
     real r__1, r__2;
     char ch__1[1], ch__2[1], ch__3[7];
     icilist ici__1;
@@ -74,7 +74,9 @@ static integer c__16 = 16;
     static integer ixchr, ipmax;
     static logical lepsl;
     static real bxmax, bxmin;
-    static integer ipmin, itype;
+    static integer ipmin;
+    static logical lsfnt;
+    static integer itype;
     extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
     static integer jtype;
     static real uxmin, uymin, uxmax, uymax, factor;
@@ -87,14 +89,14 @@ static integer c__16 = 16;
     extern /* Subroutine */ int uzcget_(char *, char *, ftnlen, ftnlen), 
 	    ulxlbl_(real *, integer *, integer *), sgqwnd_(real *, real *, 
 	    real *, real *), gnrset_(void), sgswnd_(real *, real *, real *, 
-	    real *), uxplbl_(char *, integer *, real *, char *, integer *, 
-	    integer *, ftnlen, ftnlen), sgstrf_(void), uzlget_(char *, 
-	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uxpaxs_(char 
-	    *, integer *, ftnlen), uxptmk_(char *, integer *, real *, integer 
-	    *, ftnlen);
+	    real *), swlget_(char *, logical *, ftnlen), uxplbl_(char *, 
+	    integer *, real *, char *, integer *, integer *, ftnlen, ftnlen), 
+	    sgstrf_(void), uzlget_(char *, logical *, ftnlen), uzrget_(char *,
+	     real *, ftnlen), uxpaxs_(char *, integer *, ftnlen), uxptmk_(
+	    char *, integer *, real *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
-    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };
+    static icilist io___36 = { 0, chr, 0, "(I8)", 8, 1 };
 
 
 /*     CSIDE : 'T','B','U' */
@@ -137,6 +139,7 @@ static integer c__16 = 16;
     sgiget_("IRST", &irst, (ftnlen)4);
     gllget_("LEPSL", &lepsl, (ftnlen)5);
     sglget_("LCNTL", &lcntl, (ftnlen)5);
+    swlget_("SYSFONT", &lsfnt, (ftnlen)7);
     gllset_("LEPSL", &c_true, (ftnlen)5);
     gnsave_();
 /*     SMALL TICKS */
@@ -164,7 +167,7 @@ static integer c__16 = 16;
 		msgdmp_("E", "ULXLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)15);
 	    }
-	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
+	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b29, &ip);
 L100:
 	    ;
 	}
@@ -191,14 +194,14 @@ L100:
 	    }
 	    if (ib == 1) {
 		++nbt;
-		uxt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
+		uxt[nbt - 1] = sgn * pow_ri(&c_b29, &ip);
 	    }
 	    ++nbl;
 	    if (nbl > 50) {
 		msgdmp_("E", "ULXLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)16);
 	    }
-	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
+	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b29, &ip);
 	    if (itype <= 2) {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
@@ -229,20 +232,22 @@ L100:
 			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
 				1);
 		    }
-		    s_wsfi(&io___35);
+		    s_wsfi(&io___36);
 		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
 		    e_wsfi();
 		    cladj_(chr, (ftnlen)8);
 		    if (lcntl) {
+/*              IF(LSFNT) THEN */
 /* Writing concatenation */
-			i__4[0] = 2, a__1[0] = "10";
-			csgi_(ch__1, (ftnlen)1, &isup);
-			i__4[1] = 1, a__1[1] = ch__1;
-			i__4[2] = lenz_(chr, (ftnlen)8), a__1[2] = chr;
-			csgi_(ch__2, (ftnlen)1, &irst);
-			i__4[3] = 1, a__1[3] = ch__2;
-			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__4, (
+			i__4[0] = 4, a__1[0] = "10^{";
+			i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
+			i__4[2] = 1, a__1[2] = "}";
+			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__3, (
 				ftnlen)14);
+/*              ELSE */
+/*                CH(NBL)(3:16)='1x'//CSGI(ISUP)//CHR(1:LENZ(CHR)) */
+/*     +            //CSGI(IRST) */
+/*              END IF */
 		    } else {
 /* Writing concatenation */
 			i__5[0] = 1, a__2[0] = "E";
