@@ -1,35 +1,44 @@
-/* umiqnp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__9 = 9;
+static integer c__11 = 11;
 
 /* ----------------------------------------------------------------------- */
 /*     UMIQNP / UMIQID / UMIQCP / UMIQVL / UMISVL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umiqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	integer *ipara, integer *in, ftnlen cp_len)
 {
     /* Initialized data */
 
-    static char cparas[8*9] = "INDEXMJ " "INDEXMN " "ITYPEMJ " "ITYPEMN " 
-	    "INDEXBND" "MAXBND  " "IGROUP  " "INDEXOUT" "ITYPEOUT";
-    static integer ix[9] = { 3,1,1,3,3,300,1,1,1 };
-    static char cparal[40*9] = "MAP_MAJOR_LINE_INDEX                    " 
+    static char cparas[8*11] = "INDEXMJ " "INDEXMN " "ITYPEMJ " "ITYPEMN " 
+	    "INDEXBND" "MAXBND  " "IGROUP  " "INDEXOUT" "ITYPEOUT" "IPATLAND" 
+	    "IPATLAKE";
+    static integer ix[11] = { 3,1,1,3,3,300,1,1,1,1999,9999 };
+    static char cparal[40*11] = "MAP_MAJOR_LINE_INDEX                    " 
 	    "MAP_MINOR_LINE_INDEX                    " "MAP_MAJOR_LINE_TYPE "
 	    "                    " "MAP_MINOR_LINE_TYPE                     " 
 	    "MAP_BOUNDARY_INDEX                      " "MAP_BOUNDARY_LINE_MA"
 	    "X                   " "****IGROUP                              " 
 	    "MAP_OUTLINE_INDEX                       " "MAP_OUTLINE_TYPE    "
-	    "                    ";
+	    "                    " "SHADE PATTERN ON LAND                   " 
+	    "SHADE PATTERN ON LAKE                   ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -41,9 +50,9 @@ static integer c__9 = 9;
 	     s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
-    static integer n;
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int rliget_(char *, integer *, integer *, ftnlen),
 	     msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), rtiget_(
@@ -60,12 +69,12 @@ static integer c__9 = 9;
 	}
 
 /*     / LONG NAME / */
-    *ncp = 9;
+    *ncp = 11;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_umiqid:
-    for (n = 1; n <= 9; ++n) {
+    for (n = 1; n <= 11; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -83,7 +92,7 @@ L_umiqid:
 /* ----------------------------------------------------------------------- */
 
 L_umiqcp:
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 11) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "UMIQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -93,7 +102,7 @@ L_umiqcp:
 /* ----------------------------------------------------------------------- */
 
 L_umiqcl:
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 11) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "UMIQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -104,11 +113,11 @@ L_umiqcl:
 
 L_umiqvl:
     if (lfirst) {
-	rtiget_("UM", cparas, ix, &c__9, (ftnlen)2, (ftnlen)8);
-	rliget_(cparal, ix, &c__9, (ftnlen)40);
+	rtiget_("UM", cparas, ix, &c__11, (ftnlen)2, (ftnlen)8);
+	rliget_(cparal, ix, &c__11, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 11) {
 	*ipara = ix[*idx - 1];
     } else {
 	msgdmp_("E", "UMIQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -119,11 +128,11 @@ L_umiqvl:
 
 L_umisvl:
     if (lfirst) {
-	rtiget_("UM", cparas, ix, &c__9, (ftnlen)2, (ftnlen)8);
-	rliget_(cparal, ix, &c__9, (ftnlen)40);
+	rtiget_("UM", cparas, ix, &c__11, (ftnlen)2, (ftnlen)8);
+	rliget_(cparal, ix, &c__11, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 11) {
 	ix[*idx - 1] = *ipara;
     } else {
 	msgdmp_("E", "UMISVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -133,7 +142,7 @@ L_umisvl:
 /* ----------------------------------------------------------------------- */
 
 L_umiqin:
-    for (n = 1; n <= 9; ++n) {
+    for (n = 1; n <= 11; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
