@@ -1,9 +1,16 @@
-/* umscom.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -19,12 +26,12 @@ struct {
 /* ----------------------------------------------------------------------- */
 /*     UMSCOM : COMMON BLOCK SETTING */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umscom_(void)
 {
     static logical ldeg;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int gliget_(char *, integer *, ftnlen), glrget_(
 	    char *, real *, ftnlen), sglget_(char *, logical *, ftnlen), 
 	    msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), sgqtrn_(
@@ -44,8 +51,8 @@ struct {
     }
 /* ----------------------------- ITR (CHECK)------------------------------ */
     sgqtrn_(&umwk1_1.itr);
-    if (! (10 <= umwk1_1.itr && umwk1_1.itr <= 15 || 20 <= umwk1_1.itr && 
-	    umwk1_1.itr <= 23 || 30 <= umwk1_1.itr && umwk1_1.itr <= 33)) {
+    if (! (10 <= umwk1_1.itr && umwk1_1.itr <= 24 || 30 <= umwk1_1.itr && 
+	    umwk1_1.itr <= 34)) {
 	msgdmp_("E", "UMSCOM", "INVALID TRANSFORMATION NUMBER.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)30);
     }
