@@ -1,9 +1,16 @@
-/* uxplbb.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,7 +19,7 @@ static logical c_false = FALSE_;
 /* ----------------------------------------------------------------------- */
 /*     UXPLBB : PLOT LABELS ( BETWEEN THE POINTS ) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uxplbb_(real *ux, char *ch, integer *nc, integer *n, 
 	real *upy, real *roffx, real *rsize, integer *irota, integer *icent, 
@@ -24,9 +31,11 @@ static logical c_false = FALSE_;
     real r__1;
 
     /* Local variables */
+    static integer i__, lc, lcz;
+    static real cwx, vpy, vpx, vwx, vpx1, vpx2;
     extern integer lenc_(char *, ftnlen);
     static real wxch, wych;
-    static integer i__, jrota, lc;
+    static integer jrota;
     extern /* Subroutine */ int sglget_(char *, logical *, ftnlen), msgdmp_(
 	    char *, char *, char *, ftnlen, ftnlen, ftnlen);
     static logical lclipz;
@@ -34,8 +43,6 @@ static logical c_false = FALSE_;
 	    real *, real *, real *, real *), sztxcl_(void), sztxop_(real *, 
 	    integer *, integer *, integer *), szqtxw_(char *, integer *, real 
 	    *, real *, ftnlen), sztxzv_(real *, real *, char *, ftnlen);
-    static integer lcz;
-    static real cwx, vpy, vpx, vwx, vpx1, vpx2;
 
     /* Parameter adjustments */
     ch -= ch_len;
@@ -72,7 +79,7 @@ static logical c_false = FALSE_;
 	szqtxw_(ch + i__ * ch_len, &lcz, &wxch, &wych, ch_len);
 	stftrf_(&ux[i__], upy, &vpx1, &vpy);
 	stftrf_(&ux[i__ + 1], upy, &vpx2, &vpy);
-	vwx = (r__1 = vpx2 - vpx1, dabs(r__1));
+	vwx = (r__1 = vpx2 - vpx1, abs(r__1));
 	jrota = *irota % 2;
 	if (jrota == 0) {
 	    cwx = *rsize * wxch;
