@@ -1,9 +1,16 @@
-/* vs1int.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,7 +20,7 @@ static integer c__0 = 0;
 /* ----------------------------------------------------------------------- */
 /*     VS1INT / VS1DIN / VS1OUT */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int vs1int_0_(int n__, real *wz, integer *nw, integer *ix, 
 	real *x)
@@ -22,10 +29,10 @@ static integer c__0 = 0;
     integer wz_dim1, wz_offset, i__1;
 
     /* Local variables */
+    static integer i__;
     static real xave, xvar;
     extern /* Subroutine */ int iset0_(integer *, integer *, integer *, 
 	    integer *), rset0_(real *, integer *, integer *, integer *);
-    static integer i__;
     static logical lmiss;
     static real rmiss;
     extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), glrget_(
@@ -33,7 +40,7 @@ static integer c__0 = 0;
 
     /* Parameter adjustments */
     wz_dim1 = *ix;
-    wz_offset = 1 + wz_dim1 * 1;
+    wz_offset = 1 + wz_dim1;
     wz -= wz_offset;
     --nw;
     if (x) {
